/*
 *  JacquetBlondelY.hh
 *  Rivet
 *
 *  Created by James Monk on 08/12/2008.
 *
 *  The Jacquet Blondel method for estimating y, the fraction of the beam 
 *  electron's momentum carried by the photon in HERA photoproduction, sums over 
 *  all outgoing final state hadrons as follows:
 *
 *  y \ simeq y_JB = \Sum_{hadrons} (E - P_z) / (2 E_beam)
 *
 *  Where E_beam is the energy of the incident beam electron and the +ve Z 
 *  direction is defined so that the incoming proton has positive P_z.
 *
 *
 */

#include "Rivet/Rivet.hh"
#include "Rivet/Projection.hh"
#include "Rivet/Projections/FinalState.hh"
#include "Rivet/Projections/Beam.hh"
#include "Rivet/Projections/DISLepton.hh"

namespace Rivet {
 
  class JacquetBlondelY : public Projection{
    
  public:
    
    JacquetBlondelY(const FinalState &fs){
      setName("JacquetBlondelY");
      addProjection(DISLepton(), "DISLepton");
      addProjection(Beam(), "Beam");
      addProjection(fs, "FS");
    }
    
    virtual const Projection *clone() const{
      return new JacquetBlondelY(*this);
    }
    
    virtual double y() const{
      return _y;
    }
    
  protected:
    
    virtual void project(const Event &evt);
    
    virtual int compare(const Projection &proj) const;
    
  private:
    
    double _y;
    
  };
}

